@@ -58,10 +58,12 @@ class Downloads extends AdminController
 		$setPId = Request::getInt('pId', 0);
 		$setSId = Request::getInt('sId', 0);
 
-		if ($setPId) {
+		if ($setPId)
+		{
 			Request::setVar('sId', 0);
 		}
-		elseif($setSId) {
+		elseif ($setSId)
+		{
 			Request::setVar('pId', 0);
 		}
 
@@ -290,10 +292,10 @@ class Downloads extends AdminController
 		{
 			case '1':
 				$message = Lang::txt('COM_CART_ACTIVATED', count($ids));
-			break;
+				break;
 			case '0':
 				$message = Lang::txt('COM_CART_DEACTIVATED', count($ids));
-			break;
+				break;
 		}
 
 		// Redirect
@@ -483,3 +485,4 @@ class Downloads extends AdminController
 		die;
 	}
 }
+
