@@ -496,8 +496,8 @@ class Sections extends AdminController
 					{
 						$this->setError(Lang::txt('COM_COURSES_ERROR_UPLOAD_DIRECTORY_IS_NOT_WRITABLE'));
 					}
-					// Added to allow users to overwrite their own image. 
-					// Since it accepts multipe image types, this ensures all pre-existing images are removed
+					// Added to allow users to overwrite their own image.
+					// Since it accepts multiple image types, this ensures all pre-existing images are removed
 					//   so the one they are uploading is displayed.
 					array_map('unlink', glob($uploadDirectory . 'badge.*'));
 
@@ -537,9 +537,11 @@ class Sections extends AdminController
 				if (is_object($badgesProvider))
 				{
 					$credentials = new stdClass();
-					$credentials->consumer_key    = $cconfig->get($badgeObj->get('provider_name').'_consumer_key', 0);
-					$credentials->consumer_secret = $cconfig->get($badgeObj->get('provider_name').'_consumer_secret', 0);
-					$credentials->issuerId        = $cconfig->get($badgeObj->get('provider_name').'_issuer_id');
+					$credentials->client_id = $cconfig->get($badgeObj->get('provider_name'). '_consumer_key', 0);
+					$credentials->client_secret = $cconfig->get($badgeObj->get('provider_name'). '_consumer_secret', 0);
+					$credentials->username = $cconfig->get($badgeObj->get('provider_name'). '_username', 0);
+					$credentials->password = $cconfig->get($badgeObj->get('provider_name'). '_password', 0);
+					$credentials->issuerId = $cconfig->get($badgeObj->get('provider_name'). '_issuer_id', 0);
 					$badgesProvider->setCredentials($credentials);
 
 					$offering = \Components\Courses\Models\Offering::getInstance($model->get('offering_id'));
@@ -552,7 +554,7 @@ class Sections extends AdminController
 					$data['Version']       = '1';
 					$data['BadgeImageUrl'] = rtrim(Request::root(), '/') . '/' . trim($badgeObj->get('img_url'), '/');
 
-					if (!$credentials->consumer_key || !$credentials->consumer_secret)
+					if (!$credentials->client_id || !$credentials->client_secret)
 					{
 						$this->setError(Lang::txt('COM_COURSES_ERROR_BADGE_MISSING_OPTIONS'));
 					}
