@@ -51,7 +51,7 @@ include_once(dirname(dirname(__DIR__)) . DS . 'helpers' . DS . 'filters.php');
 /**
  * Members API controller class
  */
-class Profilesv1_1 extends ApiController
+class Profilesv1_0 extends ApiController
 {
 	/**
 	 * Display a list of members
@@ -109,13 +109,6 @@ class Profilesv1_1 extends ApiController
 			'access'     => User::getAuthorisedViewLevels()
 		);
 
-		$admin = false;
-		if (User::authorise('core.admin'))
-		{
-			$admin = true;
-			$searchable = Request::getVar('searchable', false);
-		}
-
 		// Build query
 		$entries = Member::all()
 			->whereEquals('block', 0)
@@ -169,66 +162,22 @@ class Profilesv1_1 extends ApiController
 
 			foreach ($rows as $entry)
 			{
-				$fields = $entry->profiles()->rows()->toObject();
+				$obj = new stdClass;
+				$obj->id           = $entry->get('id');
+				$obj->username     = $entry->get('username');
+				$obj->name         = $entry->get('name');
+				$obj->givenName    = $entry->get('givenName');
+				$obj->middleName   = $entry->get('middleName');
+				$obj->surname      = $entry->get('surname');
+				$obj->organization = $entry->get('organization');
+				$obj->uri          = str_replace('/api', '', $base . '/' . ltrim(Route::url('index.php?option=' . $this->_option . '&id=' . $entry->get('id')), '/'));
 
-				// 1 - public
-				// 2 - register
-				// 3 - special
-				// 4 - protected
-				// 5 - private
-				if ($admin == true && isset($searchable))
-				{
-					$obj = new stdClass;
-					$obj->hubtype = 'member';
-					$obj->id = 'member-' . $entry->get('id');
-					$obj->title = $entry->get('name');
-					$obj->url = str_replace('/api', '', $base . '/' . ltrim(Route::url('index.php?option=' . $this->_option . '&id=' . $entry->get('id')), '/'));
-
-					// @TODO: Add more fields to the SOLR core.
-					$fields = $entry->profiles()->rows()->toObject();
-					$description = '';
-					foreach ($fields as $field)
-					{
-						if ($field->access == 1)
-						{
-							$description .= $field->profile_value . ' ';
-						}
-					}
-					$obj->description = $description;
-
-					$access = $entry->get('access');
-					if ($access == 1)
-					{
-						$obj->access_level = 'public';
-						$obj->owner = $entry->get('id');
-						$obj->owner_type = 'user';
-					}
-					else
-					{
-						$obj->access_level = 'private';
-						$obj->owner = $entry->get('id');
-						$obj->owner_type = 'user';
-					}
-
-					$response->members[] = $obj;
-				}
-				else
-				{
-					$obj = new stdClass;
-					$obj->id           = $entry->get('id');
-					$obj->username     = $entry->get('username');
-					$obj->name         = $entry->get('name');
-					$obj->givenName    = $entry->get('givenName');
-					$obj->middleName   = $entry->get('middleName');
-					$obj->surname      = $entry->get('surname');
-					$obj->organization = $entry->get('organization');
-					$obj->uri          = str_replace('/api', '', $base . '/' . ltrim(Route::url('index.php?option=' . $this->_option . '&id=' . $entry->get('id')), '/'));
-
-					$response->members[] = $obj;
-				}
+				$response->members[] = $obj;
 			}
 		}
+
 		$response->success = true;
+
 		$this->send($response);
 	}
 
