@@ -278,6 +278,14 @@ class Mailinglists extends AdminController
 			$filters['sort'] = 'email';
 		}
 
+		// Fix issue with going from one sorted list to another
+		if ($filters['sort'] !== 'email' && $filters['sort'] !== 'date_added' &&
+			$filters['sort'] !== 'date_confirmed')
+		{
+			$filters['sort'] = 'id';
+			$filters['sortdir'] = 'DESC';
+		}
+
 		// Load mailing list
 		$list = Mailinglist::oneOrFail($id);
 
@@ -318,7 +326,7 @@ class Mailinglists extends AdminController
 		Request::setVar('hidemainmenu', 1);
 
 		// get request vars
-		$mailinglistId = Request::getVar('id', 0);
+		$mailinglistId = Request::getVar('id', Request::getVar('mid', 0));
 		$mailinglistId = (isset($mailinglistId[0])) ? $mailinglistId[0] : 0;
 
 		// load mailing list
