@@ -32,16 +32,20 @@
 
 namespace Components\Publications\Tables;
 
+use Hubzero\Database\Table;
+use Date;
+use User;
+
 /**
  * Table class for publications
  */
-class Publication extends \JTable
+class Publication extends Table
 {
 	/**
 	 * Constructor
 	 *
-	 * @param      object &$db JDatabase
-	 * @return     void
+	 * @param   object  &$db  Database
+	 * @return  void
 	 */
 	public function __construct(&$db)
 	{
@@ -51,8 +55,8 @@ class Publication extends \JTable
 	/**
 	 * Load by alias
 	 *
-	 * @param      string 	$oid
-	 * @return     object or false
+	 * @param   string  $oid
+	 * @return  mixed   object or false
 	 */
 	public function loadPublication($oid=null)
 	{
@@ -76,8 +80,8 @@ class Publication extends \JTable
 	/**
 	 * Load by alias
 	 *
-	 * @param      string 	$oid
-	 * @return     object or false
+	 * @param   string  $oid
+	 * @return  mixed  object or false
 	 */
 	public function loadAlias($oid=null)
 	{
@@ -100,7 +104,7 @@ class Publication extends \JTable
 	/**
 	 * Check for missing fields
 	 *
-	 * @return     boolean true or false
+	 * @return  boolean  true or false
 	 */
 	public function check()
 	{
@@ -115,19 +119,21 @@ class Publication extends \JTable
 	/**
 	 * Build query
 	 *
-	 * @param      array 		$filters
-	 * @return     query string
+	 * @param   array  $filters
+	 * @param   bool   $admin
+	 * @return  query  string
 	 */
 	public function buildQuery($filters = array(), $admin = false)
 	{
-		$now 		= Date::toSql();
-		$groupby 	= ' GROUP BY C.id ';
+		$now = Date::toSql();
+		$groupby  = ' GROUP BY C.id ';
 
-		$project 		= isset($filters['project']) && intval($filters['project']) ? $filters['project'] : "";
-		$dev 			= isset($filters['dev']) && $filters['dev'] == 1 ? 1 : 0;
-		$projects 		= isset($filters['projects']) && !empty($filters['projects']) ? $filters['projects'] : array();
-		$mine 			= isset($filters['mine']) && $filters['mine'] ? $filters['mine'] : 0;
-		$sortby  		= isset($filters['sortby']) ? $filters['sortby'] : 'title';
+		$project  = isset($filters['project']) && intval($filters['project']) ? $filters['project'] : "";
+		$dev      = isset($filters['dev']) && $filters['dev'] == 1 ? 1 : 0;
+		$projects = isset($filters['projects']) && !empty($filters['projects']) ? $filters['projects'] : array();
+		$mine     = isset($filters['mine']) && $filters['mine'] ? $filters['mine'] : 0;
+		$featured = isset($filters['featured']) && $filters['featured'] ? 1 : 0;
+		$sortby   = isset($filters['sortby']) ? $filters['sortby'] : 'title';
 
 		$query  = "FROM ";
 		if (isset($filters['tag']) && $filters['tag'] != '')
@@ -147,6 +153,11 @@ class Publication extends \JTable
 		$query .= "LEFT JOIN #__publication_categories AS t ON t.id=C.category ";
 		$query .= " WHERE V.publication_id=C.id AND MT.id=C.master_type AND PP.id = C.project_id ";
 
+		if ($featured)
+		{
+			$query .=" AND C.featured = 1";
+		}
+
 		if ($dev)
 		{
 			// $query .= " AND V.main=1 ";
@@ -316,7 +327,7 @@ class Publication extends \JTable
 		}
 		if (isset($filters['tag']) && $filters['tag'] != '')
 		{
-			include_once(PATH_CORE . DS . 'components' . DS . 'com_publications' . DS . 'helpers' . DS . 'tags.php');
+			include_once dirname(__DIR__) . DS . 'helpers' . DS . 'tags.php';
 			$tagging = new \Components\Publications\Helpers\Tags($this->_db);
 			$tags = $tagging->_parse_tags($filters['tag']);
 
@@ -420,9 +431,9 @@ class Publication extends \JTable
 	/**
 	 * Get record count
 	 *
-	 * @param      array 		$filters
-	 * @param      boolean		$admin
-	 * @return     object
+	 * @param   array    $filters
+	 * @param   boolean  $admin
+	 * @return  object
 	 */
 	public function getCount($filters = array(), $admin = false)
 	{
@@ -439,9 +450,9 @@ class Publication extends \JTable
 	/**
 	 * Get records
 	 *
-	 * @param      array 		$filters
-	 * @param      boolean		$admin
-	 * @return     object
+	 * @param   array    $filters
+	 * @param   boolean  $admin
+	 * @return  object
 	 */
 	public function getRecords($filters = array(), $admin = false)
 	{
@@ -475,9 +486,9 @@ class Publication extends \JTable
 	/**
 	 * Get provisioned publication
 	 *
-	 * @param      integer		$pid
-	 * @param      boolean		$getid
-	 * @return     object
+	 * @param   integer  $pid
+	 * @param   boolean  $getid
+	 * @return  mixed    object
 	 */
 	public function getProvPublication($pid = 0, $getid = false)
 	{
@@ -507,11 +518,11 @@ class Publication extends \JTable
 	/**
 	 * Get publication
 	 *
-	 * @param      integer		$pid
-	 * @param      string		$version
-	 * @param      integer		$project_id
-	 * @param      string		$alias
-	 * @return     object
+	 * @param   integer  $pid
+	 * @param   string   $version
+	 * @param   integer  $project_id
+	 * @param   string   $alias
+	 * @return  object
 	 */
 	public function getPublication($pid = null, $version = 'default', $project_id = null, $alias = null)
 	{
@@ -540,8 +551,8 @@ class Publication extends \JTable
 				PP.owned_by_group as project_group ";
 
 		$sql .= ",(SELECT vv.version_label FROM #__publication_versions as vv
-				WHERE vv.publication_id=C.id AND (vv.state = 3 OR vv.state = 5)) AS dev_version_label ";
-		$sql .= ",(SELECT vv.state FROM #__publication_versions as vv WHERE vv.publication_id=C.id AND vv.main=1)
+				WHERE vv.publication_id=C.id AND (vv.state = 3 OR vv.state = 5) LIMIT 1) AS dev_version_label ";
+		$sql .= ",(SELECT vv.state FROM #__publication_versions as vv WHERE vv.publication_id=C.id AND vv.main=1 ORDER BY vv.created DESC LIMIT 1)
 				AS default_version_status ";
 		$sql .= ",(SELECT COUNT(*) FROM #__publication_versions WHERE publication_id=C.id AND state!=3 ) AS versions ";
 		$sql .= " FROM #__publication_versions as V, #__projects AS PP, #__publication_master_types AS MT, $this->_tbl AS C ";
@@ -576,11 +587,11 @@ class Publication extends \JTable
 	/**
 	 * Calculate rating
 	 *
-	 * @return     integer
+	 * @return  void
 	 */
 	public function calculateRating()
 	{
-		$this->_db->setQuery("SELECT rating FROM #__publication_ratings WHERE publication_id=" . $this->_db->quote($this->id));
+		$this->_db->setQuery("SELECT rating FROM `#__publication_ratings` WHERE publication_id=" . $this->_db->quote($this->id));
 		$ratings = $this->_db->loadObjectList();
 
 		$totalcount = count($ratings);
@@ -606,7 +617,7 @@ class Publication extends \JTable
 	/**
 	 * Update rating
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function updateRating()
 	{
@@ -621,8 +632,8 @@ class Publication extends \JTable
 	/**
 	 * Delete publication existence
 	 *
-	 * @param      integer 		$id
-	 * @return     void
+	 * @param   integer  $id
+	 * @return  void
 	 */
 	public function deleteExistence($id = null)
 	{
@@ -632,14 +643,14 @@ class Publication extends \JTable
 		}
 
 		// Delete tag associations
-		$this->_db->setQuery("DELETE FROM #__tags_object WHERE tbl='publications' AND objectid=". $this->_db->quote($id));
+		$this->_db->setQuery("DELETE FROM `#__tags_object` WHERE tbl='publications' AND objectid=". $this->_db->quote($id));
 		if (!$this->_db->query())
 		{
 			echo $this->_db->getErrorMsg();
 			exit;
 		}
 		// Delete ratings
-		$this->_db->setQuery("DELETE FROM #__publication_ratings WHERE publication_id=" . $this->_db->quote($id));
+		$this->_db->setQuery("DELETE FROM `#__publication_ratings` WHERE publication_id=" . $this->_db->quote($id));
 		if (!$this->_db->query())
 		{
 			echo $this->_db->getErrorMsg();
@@ -650,9 +661,10 @@ class Publication extends \JTable
 	/**
 	 * Get top-level publication stats
 	 *
-	 * @param      array 	$validProjects
-	 * @param      string 	$get
-	 * @return     mixed
+	 * @param   array   $validProjects
+	 * @param   string  $get
+	 * @param   string  $when
+	 * @return  mixed
 	 */
 	public function getPubStats($validProjects = array(), $get = 'total', $when = null)
 	{
