@@ -152,7 +152,7 @@ class plgAuthenticationFacebook extends \Hubzero\Plugin\OauthClient
 		$options['return'] = $b64dreturn;
 
 		// Check to make sure they didn't deny our application permissions
-		if (Request::getVar('error', NULL))
+		if (Request::getVar('error', null))
 		{
 			// User didn't authorize our app or clicked cancel
 			App::redirect(
@@ -226,10 +226,9 @@ class plgAuthenticationFacebook extends \Hubzero\Plugin\OauthClient
 				$id       = $user_profile->getId();
 				$fullname = $user_profile->getName();
 				$email    = $user_profile->getEmail();
-				
+
 				// Version 5 of the Facebook SDK no longer allows retrival of username
 				// $username = $user_profile->getField('username');
-
 			}
 			catch (\Facebook\Exceptions\FacebookResponseException $e)
 			{
@@ -250,7 +249,7 @@ class plgAuthenticationFacebook extends \Hubzero\Plugin\OauthClient
 				return;
 			}
 
-			$hzal->email = $email;
+			$hzal->set('email', $email);
 
 			// Set response variables
 			$response->auth_link = $hzal;
@@ -258,7 +257,7 @@ class plgAuthenticationFacebook extends \Hubzero\Plugin\OauthClient
 			$response->status    = \Hubzero\Auth\Status::SUCCESS;
 			$response->fullname  = $fullname;
 
-			if (!empty($hzal->user_id))
+			if ($hzal->user_id)
 			{
 				$user = User::getInstance($hzal->user_id);
 
@@ -362,8 +361,8 @@ class plgAuthenticationFacebook extends \Hubzero\Plugin\OauthClient
 			else
 			{
 				$hzal = \Hubzero\Auth\Link::find_or_create('authentication', 'facebook', null, $id);
-				$hzal->user_id = User::get('id');
-				$hzal->email   = $email;
+				$hzal->set('user_id', User::get('id'));
+				$hzal->set('email', $email);
 				$hzal->update();
 			}
 		}
