@@ -312,6 +312,11 @@ class plgGroupsMembers extends \Hubzero\Plugin\Plugin
 					$view->groupusers = array_values(array_filter($view->groupusers));
 				}
 
+				if (!$view->groupusers)
+				{
+					$view->groupusers = array();
+				}
+
 				// sort users before display
 				$view->groupusers = $this->sortAlphabetically($view->groupusers);
 
@@ -321,6 +326,15 @@ class plgGroupsMembers extends \Hubzero\Plugin\Plugin
 				$view->no_html = Request::getInt('no_html', 0);
 				$view->params = $this->params;
 
+				if ($view->limit > 9223372036854775807 || $view->start > 9223372036854775807)
+				{
+					App::abort(404, Lang::txt('Pagination value beyond the bounds of supported integer values.'));
+				}
+				if (intval($view->limit) < 0 || intval($view->start) < 0)
+				{
+					App::abort(404, Lang::txt('Invalid pagination value.'));
+				}
+
 				if ($this->getError())
 				{
 					$view->setError($this->getError());
@@ -430,6 +444,12 @@ class plgGroupsMembers extends \Hubzero\Plugin\Plugin
 	 */
 	private function approve()
 	{
+		// Membership cannot be changed
+		if ($this->group->get('join_policy') == 3)
+		{
+			return false;
+		}
+
 		if ($this->authorized != 'manager' && $this->authorized != 'admin')
 		{
 			return false;
@@ -771,6 +791,12 @@ class plgGroupsMembers extends \Hubzero\Plugin\Plugin
 	 */
 	private function remove()
 	{
+		// Membership cannot be changed
+		if ($this->group->get('join_policy') == 3)
+		{
+			return false;
+		}
+
 		if ($this->authorized != 'manager' && $this->authorized != 'admin')
 		{
 			return false;
@@ -932,10 +958,16 @@ class plgGroupsMembers extends \Hubzero\Plugin\Plugin
 	/**
 	 * Add members
 	 *
-	 * @return  void
+	 * @return  mixed
 	 */
 	private function add()
 	{
+		// Membership cannot be changed
+		if ($this->group->get('join_policy') == 3)
+		{
+			return false;
+		}
+
 		if ($this->authorized != 'manager' && $this->authorized != 'admin')
 		{
 			return false;
