@@ -60,17 +60,17 @@ class plgMembersResume extends \Hubzero\Plugin\Plugin
 
 		$path = Component::path('com_jobs');
 
-		include_once($path . DS . 'tables' . DS . 'admin.php');
-		include_once($path . DS . 'tables' . DS . 'application.php');
-		include_once($path . DS . 'tables' . DS . 'category.php');
-		include_once($path . DS . 'tables' . DS . 'employer.php');
-		include_once($path . DS . 'tables' . DS . 'job.php');
-		include_once($path . DS . 'tables' . DS . 'prefs.php');
-		include_once($path . DS . 'tables' . DS . 'resume.php');
-		include_once($path . DS . 'tables' . DS . 'seeker.php');
-		include_once($path . DS . 'tables' . DS . 'shortlist.php');
-		include_once($path . DS . 'tables' . DS . 'stats.php');
-		include_once($path . DS . 'tables' . DS . 'type.php');
+		include_once $path . DS . 'tables' . DS . 'admin.php';
+		include_once $path . DS . 'tables' . DS . 'application.php';
+		include_once $path . DS . 'tables' . DS . 'category.php';
+		include_once $path . DS . 'tables' . DS . 'employer.php';
+		include_once $path . DS . 'tables' . DS . 'job.php';
+		include_once $path . DS . 'tables' . DS . 'prefs.php';
+		include_once $path . DS . 'tables' . DS . 'resume.php';
+		include_once $path . DS . 'tables' . DS . 'seeker.php';
+		include_once $path . DS . 'tables' . DS . 'shortlist.php';
+		include_once $path . DS . 'tables' . DS . 'stats.php';
+		include_once $path . DS . 'tables' . DS . 'type.php';
 
 		$this->config = Component::params('com_jobs');
 	}
@@ -200,7 +200,7 @@ class plgMembersResume extends \Hubzero\Plugin\Plugin
 		// The output array we're returning
 		$arr = array(
 			'html' => '',
-			'metadata' => '',
+			'metadata' => array(),
 			'searchresult' => ''
 		);
 
@@ -225,7 +225,7 @@ class plgMembersResume extends \Hubzero\Plugin\Plugin
 		{
 			$database = App::get('db');
 
-			$task = Request::getVar('action', '');
+			$task = Request::getCmd('action', '');
 
 			switch ($task)
 			{
@@ -279,11 +279,11 @@ class plgMembersResume extends \Hubzero\Plugin\Plugin
 	 */
 	protected function _save($database, $option, $member, $task, $emp)
 	{
-		$lookingfor = Request::getVar('lookingfor', '');
-		$tagline    = Request::getVar('tagline', '');
+		$lookingfor = Request::getString('lookingfor', '');
+		$tagline    = Request::getString('tagline', '');
 		$active     = Request::getInt('activeres', 0);
 		$author     = Request::getInt('author', 0);
-		$title      = Request::getVar('title', '');
+		$title      = Request::getString('title', '');
 
 		if ($task == 'saveprefs')
 		{
@@ -516,7 +516,7 @@ class plgMembersResume extends \Hubzero\Plugin\Plugin
 		}
 
 		// Incoming
-		$title = Request::getVar('title', '');
+		$title = Request::getString('title', '');
 		$default_title = $member->get('firstname') ? $member->get('firstname') . ' ' . $member->get('lastname') . ' ' . ucfirst(Lang::txt('PLG_MEMBERS_RESUME_RESUME')) : $member->get('name') . ' ' . ucfirst(Lang::txt('PLG_MEMBERS_RESUME_RESUME'));
 		$path = PATH_APP . $path;
 
