@@ -41,14 +41,14 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Affects constructor behavior. If true, language files will be loaded automatically.
 	 *
-	 * @var    boolean
+	 * @var  boolean
 	 */
 	protected $_autoloadLanguage = true;
 
 	/**
 	 * Return the name of the area this plugin retrieves records for
 	 *
-	 * @return     array
+	 * @return  array
 	 */
 	public function onUsageAreas()
 	{
@@ -60,11 +60,12 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Get the top list for a tool
 	 *
-	 * @param      object $database JDatabase
-	 * @param      string $period   Tiem period (quarterly, yearly, etc)
-	 * @param      string $dthis    Time (YYYY-MM)
-	 * @param      string $s_top    Top value
-	 * @return     string HTML
+	 * @param   object  $database      JDatabase
+	 * @param   string  $period        Tiem period (quarterly, yearly, etc)
+	 * @param   string  $dthis         Time (YYYY-MM)
+	 * @param   string  $s_top         Top value
+	 * @param   string  $table_header
+	 * @return  string HTML
 	 */
 	private function gettoplist($database, $period, $dthis, $s_top, $table_header='Value')
 	{
@@ -107,7 +108,9 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 					$html .= "\t\t\t" . '<th colspan="2" class="numerical-data">' . $row->name . '</th>' . "\n";
 					$html .= "\t\t\t" . '<th class="numerical-data">' . $value . '</th>' . "\n";
 					if ($total)
+					{
 						$vl = number_format((($row->value/$total)*100), 2);
+					}
 					$html .= "\t\t\t" . '<th class="numerical-data">' . $vl . '%</th>' . "\n";
 					$html .= "\t\t" . '</tr>' . "\n";
 					$html .= "\t" . '</tfoot>' . "\n";
@@ -115,7 +118,7 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 				}
 				else
 				{
-					$name = preg_split('/ ~ /',$row->name);
+					$name = preg_split('/ ~ /', $row->name);
 					if ($s_top == "6" || $s_top == "7" || $s_top == "8")
 					{
 						$value = $this->time_units($row->value);
@@ -136,7 +139,9 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 					$html .= "\t\t\t" . '<td class="textual-data"><a href="'.Route::url('index.php?option=com_resources&id=' . $name[0] . '&active=usage') . '">' . $name[1] . '</a></td>' . "\n";
 					$html .= "\t\t\t" . '<td>' . $value . '</td>' . "\n";
 					if ($total)
+					{
 						$vl = number_format((($row->value/$total)*100), 2);
+					}
 					$html .= "\t\t\t" . '<td>' . $vl . '%</td>' . "\n";
 					$html .= "\t\t" . '</tr>' . "\n";
 				}
@@ -163,12 +168,12 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	}
 
 	/**
-	 * Short description for 'gettoprank_tools'
+	 * Summary for 'gettoprank_tools'
 	 *
-	 * Long description (if any) ...
+	 * Description (if any) ...
 	 *
-	 * @param      object $database Parameter description (if any) ...
-	 * @return     string Return description (if any) ...
+	 * @param   object $database Parameter description (if any) ...
+	 * @return  string Return description (if any) ...
 	 */
 	private function gettoprank_tools($database)
 	{
@@ -179,7 +184,8 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 		$database->setQuery($sql);
 		$results = $database->loadObjectList();
 
-		if ($results) {
+		if ($results)
+		{
 			$cls = 'even';
 			$html .= "\t" . '<thead>' . "\n";
 			$html .= "\t\t" . '<tr>' . "\n";
@@ -192,14 +198,15 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 			foreach ($results as $row)
 			{
 				$cls = ($cls == 'even') ? 'odd' : 'even';
-				$ranking = round($row->ranking,2);
+				$ranking = round($row->ranking, 2);
 
 				if ($ranking == 0)
 				{
 					continue;
 				}
 
-				if ($row->published == "1") {
+				if ($row->published == "1")
+				{
 					$html .= "\t\t" . '<tr class="' . $cls . '">' . "\n";
 					$html .= "\t\t\t" . '<td>' . $count . '</td>' . "\n";
 					$html .= "\t\t\t" . '<td class="textual-data"><a href="'.Route::url('index.php?option=com_resources&id=' . $row->id . '&active=usage') . '">' . $row->title . '</a></td>' . "\n";
@@ -230,8 +237,8 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Gets top cited tools
 	 *
-	 * @param      object $database JDatabase
-	 * @return     string HTML
+	 * @param   object $database JDatabase
+	 * @return  string HTML
 	 */
 	private function gettopcited_tools($database)
 	{
@@ -308,8 +315,8 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Format time
 	 *
-	 * @param      mixed $time Value to format
-	 * @return     string
+	 * @param   mixed $time Value to format
+	 * @return  string
 	 */
 	private function time_units($time)
 	{
@@ -336,11 +343,11 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Build date selectors
 	 *
-	 * @param      object &$db    JDatabase
-	 * @param      string $period Time period (quarterly, yearly, etc)
-	 * @param      string $s_top  Top value
-	 * @param      string $dthis  Time (YYYY-MM)
-	 * @return     string HTML
+	 * @param   object &$db    JDatabase
+	 * @param   string $period Time period (quarterly, yearly, etc)
+	 * @param   string $s_top  Top value
+	 * @param   string $dthis  Time (YYYY-MM)
+	 * @return  string HTML
 	 */
 	private function drop_down_dates(&$db, $period, $s_top, $dthis)
 	{
@@ -348,7 +355,7 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 			"01" => "Jan", "02" => "Feb", "03" => "Mar", "04" => "Apr", "05" => "May", "06" => "Jun",
 			"07" => "Jul", "08" => "Aug", "09" => "Sep", "10" => "Oct", "11" => "Nov", "12" => "Dec"
 			);
-		$monthsReverse = array_reverse($months, TRUE);
+		$monthsReverse = array_reverse($months, true);
 		$cur_year = floor(date("Y"));
 		$cur_month = floor(date("n"));
 		$year_data_start = 2000;
@@ -408,18 +415,34 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 							$html .= '>';
 							switch ($i)
 							{
-								case 3:  $html .= 'Jan'; break;
-								case 6:  $html .= 'Apr'; break;
-								case 9:  $html .= 'Jul'; break;
-								default: $html .= 'Oct'; break;
+								case 3:
+									$html .= 'Jan';
+									break;
+								case 6:
+									$html .= 'Apr';
+									break;
+								case 9:
+									$html .= 'Jul';
+									break;
+								default:
+									$html .= 'Oct';
+									break;
 							}
 							$html .= ' ' . $j . ' - ';
 							switch ($i)
 							{
-								case 3:  $html .= 'Mar'; break;
-								case 6:  $html .= 'Jun'; break;
-								case 9:  $html .= 'Sep'; break;
-								default: $html .= 'Dec'; break;
+								case 3:
+									$html .= 'Mar';
+									break;
+								case 6:
+									$html .= 'Jun';
+									break;
+								case 9:
+									$html .= 'Sep';
+									break;
+								default:
+									$html .= 'Dec';
+									break;
 							}
 							$html .= ' ' . $j . '</option>' . "\n";
 						}
@@ -564,12 +587,12 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	}
 
 	/**
-	 * Returns TRUE if there is data in the database
-	 * for the date passed to it, FALSE otherwise.
+	 * Returns true if there is data in the database
+	 * for the date passed to it, false otherwise.
 	 *
-	 * @param      string $yearmonth YYYY-MM
-	 * @param      string $period    Time period
-	 * @return     boolean
+	 * @param   string $yearmonth  YYYY-MM
+	 * @param   string $period     Time period
+	 * @return  boolean
 	 */
 	private function check_for_data($yearmonth, $period)
 	{
@@ -590,9 +613,9 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Build navigation menu
 	 *
-	 * @param      string $period Timeperiod
-	 * @param      string $top    Top value
-	 * @return     string HTML
+	 * @param   string $period  Timeperiod
+	 * @param   string $top     Top value
+	 * @return  string HTML
 	 */
 	private function navlinks($period='12', $top='')
 	{
@@ -643,13 +666,13 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 	/**
 	 * Event call for displaying usage data
 	 *
-	 * @param      string $option        Component name
-	 * @param      string $task          Component task
-	 * @param      object $db            JDatabase
-	 * @param      array  $months        Month names (Jan -> Dec)
-	 * @param      array  $monthsReverse Month names in reverse (Dec -> Jan)
-	 * @param      string $enddate       Time period
-	 * @return     string HTML
+	 * @param   string $option         Component name
+	 * @param   string $task           Component task
+	 * @param   object $db             JDatabase
+	 * @param   array  $months         Month names (Jan -> Dec)
+	 * @param   array  $monthsReverse  Month names in reverse (Dec -> Jan)
+	 * @param   string $enddate        Time period
+	 * @return  string HTML
 	 */
 	public function onUsageDisplay($option, $task, $db, $months, $monthsReverse, $enddate)
 	{
@@ -668,7 +691,7 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 		// Ensure the database table(s) exist
 		$tables = $database->getTableList();
 		$table = $database->getPrefix() . 'stats_tops';
-		if (!in_array($table,$tables))
+		if (!in_array($table, $tables))
 		{
 			return '<p class="error">' . Lang::txt('Error: Required database table not found . ') . '</p>';
 		}
@@ -679,10 +702,10 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 
 		// Incoming
 		$period = Request::getVar('period', '12');
-		$dthis  = Request::getVar('dthis', date('Y') . '-'.date('m'));
+		$dthis  = Request::getVar('dthis', date('Y') . '-' . date('m'));
 		if (!preg_match('/[0-9]{4}\-[0-9]{2}/', $dthis))
 		{
-			$dthis = date('Y') . '-'.date('m');
+			$dthis = date('Y') . '-' . date('m');
 		}
 		$s_top  = Request::getInt('top', '2');
 
@@ -770,4 +793,3 @@ class plgUsageTools extends \Hubzero\Plugin\Plugin
 		return $html;
 	}
 }
-
