@@ -81,7 +81,7 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 
 			$plugins = Plugin::byType('user');
 			$xuser_order = false;
-			$joomla_order = false;
+			$hubzero_order = false;
 			$i = 0;
 
 			foreach ($plugins as $plugin)
@@ -91,34 +91,34 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 					$xuser_order = $i;
 				}
 
-				if ($plugin->name == 'joomla')
+				if ($plugin->name == 'joomla' || $plugin->name == 'hubzero')
 				{
-					$joomla_order = $i;
+					$hubzero_order = $i;
 				}
 
 				$i++;
 			}
 
-			if ($joomla_order === false)
+			if ($hubzero_order === false)
 			{
-				return new Exception(Lang::txt('E_JOOMLA_USER_PLUGIN_MISCONFIGURED'), 500);
+				throw new Exception(Lang::txt('E_HUBZERO_USER_PLUGIN_MISCONFIGURED'), 500);
 			}
 
-			if ($xuser_order <= $joomla_order)
+			if ($xuser_order <= $hubzero_order)
 			{
-				return new Exception(Lang::txt('E_HUBZERO_USER_PLUGIN_MISCONFIGURED'), 500);
+				throw new Exception(Lang::txt('E_HUBZERO_USER_PLUGIN_MISCONFIGURED'), 500);
 			}
 
-			return new Exception(Lang::txt('E_JOOMLA_USER_PLUGIN_FAILED'), 500);
+			throw new Exception(Lang::txt('E_HUBZERO_USER_PLUGIN_FAILED'), 500);
 		}
 
 		// log login to auth log
 		Log::auth($xuser->get('id') . ' [' . $xuser->get('username') . '] ' . $_SERVER['REMOTE_ADDR'] . ' login');
 
 		// correct apache log data
-		if (strpos(php_sapi_name(),'apache') !== false)
+		if (function_exists('apache_note'))
 		{
-			apache_note('auth','login');
+			apache_note('auth', 'login');
 		}
 
 		// Log attempt to the database
@@ -239,7 +239,7 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 
 				if ($hzal)
 				{
-					$hzal->user_id = $xuser->get('id');
+					$hzal->set('user_id', $xuser->get('id'));
 					$hzal->update();
 				}
 			}
@@ -258,7 +258,7 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 
 		if ($params->get('manage_quotas', false))
 		{
-			require_once PATH_CORE . DS . 'components' . DS . 'com_members' . DS . 'models' . DS . 'quota.php';
+			require_once Component::path('com_members') . DS . 'models' . DS . 'quota.php';
 
 			$quota = Components\Members\Models\Quota::all()
 				->whereEquals('user_id', $xuser->get('id'))
@@ -378,12 +378,12 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 				{
 					$db = App::get('db');
 
-					$component = new JTableExtension($this->database);
-					$component->load($component->find(array('element' => 'com_members', 'type' => 'component')));
-					$params = new \Hubzero\Config\Registry($component->params);
+					$params = Component::params('com_members');
 					$params->set('homedir', $hubHomeDir);
-					$component->params = $params->toString();
-					$component->store();
+
+					$query = "UPDATE `#__extensions` SET `params` = " . $db->quote($params->toString()) . " WHERE `type`='component' AND `element`=" . $db->quote('com_members');
+					$db->setQuery($query);
+					$db->query();
 				}
 			}
 
@@ -435,12 +435,6 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 				$update = true;
 			}
 
-			if ($xprofile->get('homeDirectory') != $user['homeDirectory'])
-			{
-				$xprofile->set('homeDirectory', $user['homeDirectory']);
-				$update = true;
-			}
-
 			// Fix missing surname/given name as well
 			if ($xprofile->get('name') && (!$xprofile->get('surname') || !$xprofile->get('givenName')))
 			{
@@ -554,7 +548,7 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 
 		if ($params->get('manage_quotas', false))
 		{
-			require_once PATH_CORE . DS . 'components' . DS . 'com_members' . DS . 'models' . DS . 'quota.php';
+			require_once Component::path('com_members') . DS . 'models' . DS . 'quota.php';
 
 			$quota = Components\Members\Models\Quota::all()
 				->whereEquals('user_id', $user['id'])
@@ -659,7 +653,7 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 		\Hubzero\Auth\Link::delete_by_user_id($user['id']);
 
 		// Check if quota exists for the user
-		require_once PATH_CORE . DS . 'components' . DS . 'com_members' . DS . 'models' . DS . 'quota.php';
+		require_once Component::path('com_members') . DS . 'models' . DS . 'quota.php';
 
 		$quota = Components\Members\Models\Quota::all()
 			->whereEquals('user_id', $user['id'])
@@ -701,9 +695,9 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 	{
 		Log::auth($user['username'] . ' ' . $_SERVER['REMOTE_ADDR'] . ' logout');
 
-		if (strpos(php_sapi_name(),'apache') !== false)
+		if (function_exists('apache_note'))
 		{
-			apache_note('auth','logout');
+			apache_note('auth', 'logout');
 		}
 
 		// If this is a temporary user created during the auth_link process (ex: username is a negative number)
@@ -727,7 +721,7 @@ class plgUserXusers extends \Hubzero\Plugin\Plugin
 	/**
 	 * Hook for login failure
 	 *
-	 * @param   unknown  $response
+	 * @param   array    $response
 	 * @return  boolean
 	 */
 	public function onUserLoginFailure($response)
